Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5702)

Unified Diff: chrome/browser/task_profiler/task_profiler_data_serializer.h

Issue 985773002: Introducing phased profiling framework (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@write_to_file
Patch Set: Fixing Android compile errors. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/task_profiler/task_profiler_data_serializer.h
diff --git a/chrome/browser/task_profiler/task_profiler_data_serializer.h b/chrome/browser/task_profiler/task_profiler_data_serializer.h
index 09df47ee64f0884a123f9280d8e8dedb950f9072..1b5c8d002bde819dbf46ac6a062f85fb6678e1cc 100644
--- a/chrome/browser/task_profiler/task_profiler_data_serializer.h
+++ b/chrome/browser/task_profiler/task_profiler_data_serializer.h
@@ -6,6 +6,7 @@
#define CHROME_BROWSER_TASK_PROFILER_TASK_PROFILER_DATA_SERIALIZER_H_
#include "base/basictypes.h"
+#include "base/process/process_handle.h"
namespace base {
class DictionaryValue;
@@ -13,7 +14,7 @@ class FilePath;
}
namespace tracked_objects {
-struct ProcessDataSnapshot;
+struct ProcessDataPhaseSnapshot;
}
namespace task_profiler {
@@ -24,10 +25,13 @@ class TaskProfilerDataSerializer {
public:
TaskProfilerDataSerializer() {}
- // Writes the contents of |process_data| and |process_type| into |dictionary|.
- static void ToValue(const tracked_objects::ProcessDataSnapshot& process_data,
- int process_type,
- base::DictionaryValue* dictionary);
+ // Writes the contents of |process_data_phase|, |process_id| and
+ // |process_type| into |dictionary|.
+ static void ToValue(
+ const tracked_objects::ProcessDataPhaseSnapshot& process_data_phase,
+ base::ProcessId process_id,
+ int process_type,
+ base::DictionaryValue* dictionary);
private:
DISALLOW_COPY_AND_ASSIGN(TaskProfilerDataSerializer);
« no previous file with comments | « chrome/browser/metrics/chrome_metrics_service_client.cc ('k') | chrome/browser/task_profiler/task_profiler_data_serializer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698